@@ -105,7 +105,16 @@ def interactive_plot_factory(ax, f, x=None,
             params[key] = val[0]
             controls.append(selector)
             selector.observe(partial(update, key = key, label=None), names=['value'])
-            
+        elif isinstance(val, widgets.Widget) or isinstance(val, widgets.fixed):
+            if not hasattr(val, 'value'):
+                raise TypeError("widgets passed as parameters must have the `value` trait."
+                                "But the widget passed for {key} does not have a `.value` attribute")
+            if isinstance(val, widgets.fixed):
+                params[key] = val.value
+            else:
+                params[key] = val.value
+                controls.append(val)
+                val.observe(partial(update, key =key, label=None), names=['value'])
         else:
             if isinstance(val, tuple) and len(val) in [2, 3]:
                 # treat as an argument to linspace
@@ -140,12 +149,23 @@ def interactive_plot_factory(ax, f, x=None,
 
 
     if plot_kwargs is None:
-        plot_kwargs = []
-        for f in funcs:
-            plot_kwargs.append({'label':f.__name__})
+        plot_kwargs = [{}] * len(funcs)
     else:
         plot_kwargs = atleast_1d(plot_kwargs)
-        assert len(plot_kwargs) == len(funcs)
+        if not len(plot_kwargs) == len(funcs):
+            raise ValueError('If using multiple functions'
+                            ' then plot_kwargs must be a list'
+                            ' of the same length or None.')
+    
+    # make sure plot labels make sense
+    for i, (pk, f) in enumerate(zip(plot_kwargs, funcs)):
+        if pk is None:
+            pk = {}
+            plot_kwargs[i] = pk
+        if 'label' not in pk:
+            pk['label'] = f.__name__
+
+
 
     lines = []
     for i,f in enumerate(funcs):
@@ -213,18 +233,22 @@ def interactive_plot(f, x=None, x_scale='stretch', y_scale='stretch',
 
     Examples 
     --------
-    x = np.linspac(0,2*np.pi)
-    tau = np.linspace(0, np.pi)
-    def f(x, tau):
-        return np.sin(x+tau)
-    interactive_plot(f, x=x, tau=tau)
 
-    --------
+    With numpy arrays::
+
+        x = np.linspac(0,2*np.pi)
+        tau = np.linspace(0, np.pi)
+        def f(x, tau):
+            return np.sin(x+tau)
+        interactive_plot(f, x=x, tau=tau)
+
+    with tuples::
+
+        x = np.linspac(0,2*np.pi)
+        def f(x, tau):
+            return np.sin(x+tau)
+        interactive_plot(f, x=x, tau=(0, np.pi, 1000))
 
-    x = np.linspac(0,2*np.pi)
-    def f(x, tau):
-        return np.sin(x+tau)
-    interactive_plot(f, x=x, tau=(0, np.pi, 1000))
     """
                                  
     backend = get_backend().lower()
